@@ -342,11 +342,6 @@ class PyTestRailPlugin(object):
                          and sub['status_id'] == TESTRAIL_TEST_STATUS['failed']), None)
             if item is None or data['status_id'] == TESTRAIL_TEST_STATUS['failed']:
                 self.results.append(data)
-            # elif item['status_id'] == TESTRAIL_TEST_STATUS['passed'] and \
-            #         data['status_id'] == TESTRAIL_TEST_STATUS['failed']:
-            #     item['status_id'] = data['status_id']
-            #     item['comment'] = data['comment']
-            #     item['defects'] = data['defects']
 
     def add_results(self, testrun_id):
         """
@@ -542,8 +537,9 @@ class PyTestRailPlugin(object):
         :return: the list of tests containing in a testrun.
 
         """
-        response = self.client.send_get(
+        response = self.client.send_gets(
             GET_TESTS_URL.format(run_id),
+            "tests",
             cert_check=self.cert_check
         )
         error = self.client.get_error(response)
